Flask-Dance — Flask Dance 1.1.0 documentation

# Flask-Dance

Doing the OAuth dance with style using Flask, requests, and oauthlib. Currently, only OAuth consumers are supported, but this project could easily support OAuth providers in the future, as well.

User Guide:

- Installation
- Library development
- Quickstarts
  - GitHub Quickstart
  - Google Quickstart
  - Twitter Quickstart
  - Dropbox Quickstart
  - Meetup Quickstart
  - Slack Quickstart
  - Azure Quickstart
  - Nylas Quickstart
  - SQLAlchemy Multi-User Quickstart
- Providers
  - Facebook
  - GitHub
  - GitLab
  - Google
  - Twitter
  - JIRA
  - Dropbox
  - Meetup
  - Slack
  - Azure
  - Nylas
  - Spotify
  - Discord
  - Okta
  - Zoho
  - Custom
- Backends
  - SQLAlchemy
  - Custom
- Multi-User Setups
  - Defining Expected Behavior
  - Flask-Dance’s Default Behavior
  - Overriding the Default Behavior
- Logging Out
  - Local Accounts vs Provider Accounts
  - Log Out Local Account
  - Revoking Access with the Provider
  - Log Out Provider Account
- Proxies and HTTPS
- Signals

Advanced Topics:

- How OAuth Works
  - Definitions
  - OAuth 2
  - OAuth 1
  - Dance Complete
- Testing
  - Creating a session
  - Calling authenticated APIs
- Developer Interface
  - Consumers
  - Backends

# Indices and tables

- Index
- Module Index
- Search Page

Fork me on GitHub